@@ -28,6 +28,8 @@ class BOTAN_DLL EMSA_PKCS1v15 final : public EMSA
       */
       explicit EMSA_PKCS1v15(HashFunction* hash);
 
+      EMSA* clone() override { return new EMSA_PKCS1v15(m_hash->clone()); }
+
       void update(const byte[], size_t) override;
 
       secure_vector<byte> raw_data() override;
@@ -50,6 +52,8 @@ class BOTAN_DLL EMSA_PKCS1v15 final : public EMSA
 class BOTAN_DLL EMSA_PKCS1v15_Raw final : public EMSA
    {
    public:
+      EMSA* clone() override { return new EMSA_PKCS1v15_Raw(); }
+
       void update(const byte[], size_t) override;
 
       secure_vector<byte> raw_data() override;
